package com.srs.comprehensive.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.comprehensive.domain.SrsCqScore;
import com.srs.comprehensive.domain.SrsStuYear;
import com.srs.comprehensive.domain.SrsStuYearS;
import com.srs.comprehensive.domain.Vo.StuYearIdName;
import org.apache.ibatis.annotations.Mapper;

/**
 * 【学年表】Mapper接口
 * 
 * @author srs
 * @date 2023-06-28
 */
@Mapper
public interface SrsStuYearMapper extends BaseMapper<SrsStuYear>
{

    public List<SrsStuYear> listEnableYear();

    public List<StuYearIdName> selectStuYearIdName();

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SrsStuYear selectSrsStuYearById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param srsStuYear 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SrsStuYear> selectSrsStuYearList(SrsStuYear srsStuYear);

    public List<SrsStuYear> selectSrsStuYearLists();

    /**
     * 新增【请填写功能名称】
     * 
     * @param srsStuYear 【请填写功能名称】
     * @return 结果
     */
    public int insertSrsStuYear(SrsStuYear srsStuYear);

    /**
     * 修改【请填写功能名称】
     * 
     * @param srsStuYear 【请填写功能名称】
     * @return 结果
     */
    public int updateSrsStuYear(SrsStuYear srsStuYear);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSrsStuYearById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSrsStuYearByIds(Long[] ids);


}
